'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _childProcessPromise;

function _load_childProcessPromise() {
  return _childProcessPromise = _interopRequireDefault(require('child-process-promise'));
}

var _ramda;

function _load_ramda() {
  return _ramda = _interopRequireDefault(require('ramda'));
}

var _ramda2;

function _load_ramda2() {
  return _ramda2 = require('ramda');
}

var _decamelize;

function _load_decamelize() {
  return _decamelize = _interopRequireDefault(require('decamelize'));
}

var _chalk;

function _load_chalk() {
  return _chalk = _interopRequireDefault(require('chalk'));
}

var _fsExtra;

function _load_fsExtra() {
  return _fsExtra = _interopRequireDefault(require('fs-extra'));
}

var _path;

function _load_path() {
  return _path = _interopRequireDefault(require('path'));
}

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var spawn = (_childProcessPromise || _load_childProcessPromise()).default.spawn;
var objectToArray = function objectToArray(obj) {
  return (0, (_ramda2 || _load_ramda2()).map)((0, (_ramda2 || _load_ramda2()).join)('@'), (0, (_ramda2 || _load_ramda2()).toPairs)(obj));
};
var rejectNils = (_ramda || _load_ramda()).default.reject((_ramda2 || _load_ramda2()).isNil);

var defaults = {
  cwd: process.cwd(),
  global: false,
  save: false,
  saveDev: false,
  saveOptional: false,
  saveExact: false,
  saveBundle: false,
  force: false,
  dryRun: false,
  ignoreScripts: false,
  legacyBundling: false,
  noOptional: false,
  noShrinkwrap: false
};

var camelCaseToOptionCase = function camelCaseToOptionCase(optName) {
  return '--' + (0, (_decamelize || _load_decamelize()).default)(optName, '-');
}; // eslint-disable-line

var serializeOption = function serializeOption(bool, optName) {
  if (optName === 'cwd') return null;
  if (!bool) return null;
  return camelCaseToOptionCase(optName);
};

var installAction = function installAction(modules, userOpts, verbose) {
  var options = (0, (_ramda2 || _load_ramda2()).merge)(defaults, userOpts);
  var flags = (0, (_ramda2 || _load_ramda2()).pipe)((0, (_ramda2 || _load_ramda2()).mapObjIndexed)(serializeOption), rejectNils, (_ramda2 || _load_ramda2()).values)(options);

  // taking care of object case
  modules = (0, (_ramda2 || _load_ramda2()).is)(Object, modules) && !Array.isArray(modules) ? objectToArray(modules) : modules;
  // taking care of string and no modules cases
  // $FlowFixMe
  modules = Array.isArray(modules) ? modules : modules && [modules] || []; // eslint-disable-line

  var serializedModules = modules && modules.length > 0 ? ` ${modules.join(' ')}` : '';
  var serializedFlags = flags && flags.length > 0 ? ` ${flags.join(' ')}` : '';

  (_fsExtra || _load_fsExtra()).default.ensureDirSync((_path || _load_path()).default.join(options.cwd, 'node_modules'));

  var args = ['install'].concat(_toConsumableArray(serializedModules.trim().split(' ')), [serializedFlags]);
  var promise = spawn('npm', args, { cwd: options.cwd });
  var childProcess = promise.childProcess;
  var stdoutOutput = [];
  var stderrOutput = [];

  childProcess.stdout.on('data', function (data) {
    return stdoutOutput.push(data.toString());
  });
  childProcess.stderr.on('data', function (data) {
    return stderrOutput.push(data.toString());
  });

  return promise.then(function () {
    var stdout = verbose ? stdoutOutput.join('') : `successfully ran npm install${serializedModules}${serializedFlags}`;
    var stderr = verbose ? stderrOutput.join('') : '';
    return { stdout, stderr };
  });
};
var printResults = function printResults(_ref) {
  var stdout = _ref.stdout,
      stderr = _ref.stderr;

  console.log((_chalk || _load_chalk()).default.yellow(stdout)); // eslint-disable-line
  console.log((_chalk || _load_chalk()).default.yellow(stderr)); // eslint-disable-line
};

exports.default = {
  install: installAction,
  printResults
};